package net.sf.r4h;


/**
 * A set of methods which allow shorter passing parameters to HibernateRepository in shorter form.
 * 
 * e.g if you static import {@link Restrictions} and  {@link HibernateRepositoryUtils} instead of calling:
 * userRepository.list(properties("firstName","lastName"), restrictions(Restrictions.equal(),Restrictions.ilike()), values("John","D%"),page(1,10));
 * you can have:
 * userRepository.list(properties("firstName","lastName"), restrictions(equal(),ilike()), values("John","D%"),page(1,10));
 * or even:
 * userRepository.list(p("firstName","lastName"), r(equal(),ilike()), v("John","D%"),p(1,10));
 * 
 * 
 * @author vitaly.se@gmail.com
 * 
 * @since 4.0.0
 * 
 */
public class HibernateRepositoryUtils {

	/**
	 * a method to avoid creating arrays of property names with new String[]{"properyName1","properyName2"} approach
	 * 
	 * @param names
	 * @return an array of properties
	 */
	public static String[] properties(String... properties) {
		return properties;
	}

	/**
	 * a short version of method to avoid creating arrays of property names with new String[]{"properyName1","properyName2"} approach
	 * 
	 * @param names
	 * @return an array of properties
	 */
	public static String[] p(String... properties) {
		return properties(properties);
	}

	/**
	 * A method to avoid creating arrays of parameters with new {@link Restrictions} [ ]{Restriction.someRestrcion1,Restriction.someRestrcion2} approach
	 * 
	 * @param restrictions
	 * @return an array of restrictions
	 */
	public static Restrictions.Restriction[] restrictions(Restrictions.Restriction... restrictions) {
		return restrictions;
	}

	/**
	 * A short version of method to avoid creating arrays of parameters with new {@link Restrictions} [ ]{Restriction.someRestrcion1,Restriction.someRestrcion2} approach
	 * 
	 * @param restrictions
	 * @return an array of restrictions
	 */
	public static Restrictions.Restriction[] r(Restrictions.Restriction... restrictions) {
		return restrictions(restrictions);
	}

	/**
	 * A method to avoid creating arrays of values for restricting properties with new Object[]{"value1","value2"} approach
	 * 
	 * @param values
	 * @return an array of values
	 */
	public static Object[] values(Object... values) {
		return values;
	}

	/**
	 * A short version of method to avoid creating arrays of values for restricting properties with new Object[]{"value1","value2"} approach
	 * 
	 * @param values
	 * @return an array of values
	 */
	public static Object[] v(Object... values) {
		return values;
	}

	/**
	 * A short version of creating page
	 * 
	 * @param number page number
	 * @param size page size
	 * @return page
	 */
	public static Page page(int number, int size) {
		return new Page(number, size);
	}

	/**
	 * 
	 * @param number page number
	 * @param size page size
	 * @return page
	 */
	public static Page p(int number, int size) {
		return new Page(number, size);
	}

}
